
if (CMAKE_VERSION VERSION_LESS 3.1.0)
    message(FATAL_ERROR "Qt 5 RepParser module requires at least CMake version 3.1.0")
endif()

# redirect to static package overriding variant prefix so it does not contain Static anymore
option(USE_STATIC_QT_BY_DEFAULT "specifies whether to use static Qt by default (rather than via Static-prefix)" OFF)
if(USE_STATIC_QT_BY_DEFAULT)
    set(ORIGINAL_OVERRIDE_QT_VARIANT_PREFIX ${OVERRIDE_QT_VARIANT_PREFIX})
    if(OVERRIDE_QT_VARIANT_PREFIX)
        string(REPLACE "Static" "" OVERRIDE_QT_VARIANT_PREFIX ${OVERRIDE_QT_VARIANT_PREFIX})
    endif()
    if(NOT OVERRIDE_QT_VARIANT_PREFIX)
        set(OVERRIDE_QT_VARIANT_PREFIX none)
    endif()
    find_package(StaticQt5RepParser)
    set(OVERRIDE_QT_VARIANT_PREFIX ${ORIGINAL_OVERRIDE_QT_VARIANT_PREFIX})
    return()
endif()

if(OVERRIDE_QT_VARIANT_PREFIX)
    if(OVERRIDE_QT_VARIANT_PREFIX STREQUAL none)
        unset(QT_VARIANT_PREFIX)
    else()
        set(QT_VARIANT_PREFIX ${OVERRIDE_QT_VARIANT_PREFIX})
    endif()
else()
    set(QT_VARIANT_PREFIX "")
endif()

get_filename_component(_qt5RepParser_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)


macro(_qt5_RepParser_check_file_exists FILE)
    if(NOT EXISTS "${FILE}")
        message(FATAL_ERROR "The imported target \"${QT_VARIANT_PREFIX}Qt5::RepParser\" references the file
   \"${FILE}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()



set(TARGET_NAME ${QT_VARIANT_PREFIX}Qt5::RepParser)

if(NOT TARGET ${TARGET_NAME})
    set(_Qt5RepParser_OWN_INCLUDE_DIRS "${_qt5RepParser_install_prefix}/include/qt/" "${_qt5RepParser_install_prefix}/include/qt/QtRepParser")
    set(${QT_VARIANT_PREFIX}Qt5RepParser_PRIVATE_INCLUDE_DIRS "")
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5RepParser_OWN_INCLUDE_DIRS})
        _qt5_RepParser_check_file_exists(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5RepParser_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5RepParser_PRIVATE_INCLUDE_DIRS})
            _qt5_RepParser_check_file_exists(${_dir})
        endforeach()
    endif()

    set(_Qt5RepParser_MODULE_DEPENDENCIES "Core")


    set(${QT_VARIANT_PREFIX}Qt5RepParser_OWN_PRIVATE_INCLUDE_DIRS ${Qt5RepParser_PRIVATE_INCLUDE_DIRS})

    set(_Qt5RepParser_FIND_DEPENDENCIES_REQUIRED)
    if (${QT_VARIANT_PREFIX}Qt5RepParser_FIND_REQUIRED)
        set(_Qt5RepParser_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5RepParser_FIND_DEPENDENCIES_QUIET)
    if (Qt5RepParser_FIND_QUIETLY)
        set(_Qt5RepParser_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5RepParser_FIND_VERSION_EXACT)
    if (${QT_VARIANT_PREFIX}Qt5RepParser_FIND_VERSION_EXACT)
        set(_Qt5RepParser_FIND_VERSION_EXACT EXACT)
    endif()


    foreach(_module_dep ${_Qt5RepParser_MODULE_DEPENDENCIES})
        if (NOT ${QT_VARIANT_PREFIX}Qt5${_module_dep}_FOUND)
            find_package(${QT_VARIANT_PREFIX}Qt5${_module_dep}
                5.12.1 ${_Qt5RepParser_FIND_VERSION_EXACT}
                ${_Qt5RepParser_DEPENDENCIES_FIND_QUIET}
                ${_Qt5RepParser_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT ${QT_VARIANT_PREFIX}Qt5${_module_dep}_FOUND)
            set(${QT_VARIANT_PREFIX}Qt5RepParser_FOUND False)
            return()
        endif()

    endforeach()

    set(_Qt5RepParser_LIB_DEPENDENCIES "${QT_VARIANT_PREFIX}Qt5::Core")


    add_library(${QT_VARIANT_PREFIX}Qt5::RepParser INTERFACE IMPORTED)



    set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::RepParser PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5RepParser_OWN_INCLUDE_DIRS})
    set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::RepParser PROPERTY
        INTERFACE_COMPILE_DEFINITIONS QT_REPPARSER_LIB)

    set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::RepParser PROPERTY INTERFACE_QT_ENABLED_FEATURES )
    set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::RepParser PROPERTY INTERFACE_QT_DISABLED_FEATURES )

    # Find plugin targets
    file(GLOB pluginTargetsMaybe "${CMAKE_CURRENT_LIST_DIR}/*Qt5RepParser_*.cmake")
    unset(pluginTargets)
    if(pluginTargetsMaybe)
        foreach(pluginTarget ${pluginTargetsMaybe})
            file(STRINGS ${pluginTarget} matched REGEX Qt5RepParser_PLUGINS)
            if(matched)
                list(APPEND pluginTargets ${pluginTarget})
            endif()
        endforeach()
    endif()

    macro(_populate_RepParser_plugin_properties TARGET_NAME PLUGIN_TARGET_NAME PLUGIN_NAME CONFIG PLUGIN_LOCATION)
        set_property(TARGET ${PLUGIN_TARGET_NAME} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${CONFIG})

        set(imported_location "${_qt5RepParser_install_prefix}/lib/qt/plugins/${PLUGIN_LOCATION}")
        _qt5_RepParser_check_file_exists(${imported_location})
        set_target_properties(${PLUGIN_TARGET_NAME} PROPERTIES
            "IMPORTED_LOCATION_${CONFIG}" ${imported_location}
        )

    endmacro()

    if(pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()

    set(_Qt5RepParser_PRIVATE_DIRS_EXIST TRUE)
    foreach (_Qt5RepParser_PRIVATE_DIR ${${QT_VARIANT_PREFIX}Qt5RepParser_OWN_PRIVATE_INCLUDE_DIRS})
        if (NOT EXISTS ${_Qt5RepParser_PRIVATE_DIR})
            set(_Qt5RepParser_PRIVATE_DIRS_EXIST FALSE)
        endif()
    endforeach()

    if (_Qt5RepParser_PRIVATE_DIRS_EXIST)
        add_library(${QT_VARIANT_PREFIX}Qt5::RepParserPrivate INTERFACE IMPORTED)
        set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::RepParserPrivate PROPERTY
            INTERFACE_INCLUDE_DIRECTORIES ${${QT_VARIANT_PREFIX}Qt5RepParser_OWN_PRIVATE_INCLUDE_DIRS}
        )
        set(_Qt5RepParser_PRIVATEDEPS)
        foreach(dep ${_Qt5RepParser_LIB_DEPENDENCIES})
            if (TARGET ${dep}Private)
                list(APPEND _Qt5RepParser_PRIVATEDEPS ${dep}Private)
            endif()
        endforeach()
        set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::RepParserPrivate PROPERTY
            INTERFACE_LINK_LIBRARIES ${QT_VARIANT_PREFIX}Qt5::RepParser ${_Qt5RepParser_PRIVATEDEPS}
        )
    endif()

    set_target_properties(${QT_VARIANT_PREFIX}Qt5::RepParser PROPERTIES
        INTERFACE_LINK_LIBRARIES "${_Qt5RepParser_LIB_DEPENDENCIES}"
    )


_qt5_RepParser_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/../${QT_VARIANT_PREFIX}Qt5RepParser/${QT_VARIANT_PREFIX}Qt5RepParserConfigVersion.cmake")

endif()
